@@ -10,10 +10,11 @@ use Facebook::InstantArticle::Copyright;
 use Facebook::InstantArticle::Embed;
 use Facebook::InstantArticle::Figure::Image;
 use Facebook::InstantArticle::Figure::Video;
+use Facebook::InstantArticle::Heading;
 use Facebook::InstantArticle::List;
 use Facebook::InstantArticle::Paragraph;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =encoding utf-8
 
@@ -307,6 +308,23 @@ sub add_embed {
     push( @{$self->_body_elements}, Facebook::InstantArticle::Embed->new(@_) );
 }
 
+=head2 add_heading
+
+Adds a heading to the article BODY.
+
+    $ia->add_heading(
+        level => 1,
+        text  => 'Heading',
+    );
+
+=cut
+
+sub add_heading {
+    my $self = shift;
+
+    push( @{$self->_body_elements}, Facebook::InstantArticle::Heading->new(@_) );
+}
+
 =head2 to_string
 
 Generates the instant article and returns it as a string.
